# Makefile for LuaPcre.dll, LuaPcre_nr.dll, LuaPosix1.dll and LuaPosix2.dll -
# using Borland tools under Windows (bcc32.exe, make.exe, etc.)
#
# This file is not generic. It reflects a specific configuration of
# the author's system and will not work in different configurations
# without modifications. It is provided in hope it may be useful for
# Windows users.
#
# author: Shmuel Zeigerman (shmuz@actcom.co.il)
#

#==========================================================================
#   POSIX1          --> the library by:   Henry Spencer
#   POSIX2          --> the library by:   John Maddock
#   PCRE, PCRE_NR   --> the library by:   Philip Hazel
#==========================================================================

DEFINES      = -DLUALIB_API=__declspec(dllexport)
INC_LUA      = ./lua
LIBD_LUA     = ./lua


# PCRE, multi-threaded build
#==========================================================================
DEF_PCRE     = $(DEFINES) -DLREXLIB_PCRE
INC_PCRE     = $(INC_LUA);./pcre
LIBS_PCRE    = lua.lib libpcre_mt.lib
LIBD_PCRE    = $(LIBD_LUA);./pcre
TARG_PCRE    = luapcre
FLAGS_PCRE   = -A -tWD -tWM

# PCRE with recursion disabled, multi-threaded build
#==========================================================================
LIBS_PCRE_NR = lua.lib libpcre_nr_mt.lib
TARG_PCRE_NR = luapcre_nr


# POSIX1, single-threaded build
#==========================================================================
DEF_POSIX1   = $(DEFINES) -DLREXLIB_POSIX
INC_POSIX1   = $(INC_LUA);./spencer
LIBS_POSIX1  = lua.lib libregex-bcc.lib
LIBD_POSIX1  = $(LIBD_LUA);./spencer
TARG_POSIX1  = luaposix1
FLAGS_POSIX1 = -A -tWD


# POSIX2, multi-threaded build
#==========================================================================
#
# File regex.hpp was copied from $(DIR_POSIX2)/boost to $(DIR_POSIX2)
#
DIR_POSIX2   = E:/boost_1_31_0
DEF_POSIX2   = $(DEFINES) -DLREXLIB_POSIX
INC_POSIX2   = $(INC_LUA);$(DIR_POSIX2);$(DIR_POSIX2)/boost
LIBS_POSIX2  = lua.lib libboost_regex-bcb-mt-s-1_31.lib
LIBD_POSIX2  = $(LIBD_LUA);$(DIR_POSIX2)/libs/regex/build/bcb
TARG_POSIX2  = luaposix2
FLAGS_POSIX2 = -tWD -tWM


all : $(TARG_PCRE).dll $(TARG_PCRE_NR).dll $(TARG_POSIX1).dll $(TARG_POSIX2).dll

$(TARG_PCRE).dll : lrexlib.c
	bcc32 $(FLAGS_PCRE) -I$(INC_PCRE) -L$(LIBD_PCRE) -e$(TARG_PCRE) \
          $(DEF_PCRE) lrexlib.c $(LIBS_PCRE)

$(TARG_PCRE_NR).dll : lrexlib.c
	bcc32 $(FLAGS_PCRE) -I$(INC_PCRE) -L$(LIBD_PCRE) -e$(TARG_PCRE_NR) \
          $(DEF_PCRE) lrexlib.c $(LIBS_PCRE_NR)

$(TARG_POSIX1).dll : lrexlib.c
	bcc32 $(FLAGS_POSIX1) -I$(INC_POSIX1) -L$(LIBD_POSIX1) -e$(TARG_POSIX1) \
          $(DEF_POSIX1) lrexlib.c $(LIBS_POSIX1)

$(TARG_POSIX2).dll : lrexlib.c
	bcc32 $(FLAGS_POSIX2) -I$(INC_POSIX2) -L$(LIBD_POSIX2) -e$(TARG_POSIX2) \
          $(DEF_POSIX2) lrexlib.c $(LIBS_POSIX2)

clean :
	if exist lrexlib.obj del lrexlib.obj
	if exist $(TARG_PCRE).tds     del $(TARG_PCRE).tds
	if exist $(TARG_PCRE_NR).tds  del $(TARG_PCRE_NR).tds
	if exist $(TARG_POSIX1).tds   del $(TARG_POSIX1).tds
	if exist $(TARG_POSIX2).tds   del $(TARG_POSIX2).tds

